@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 import os
@@ -12,10 +13,11 @@ def test_pep8():
         '--statistics',
         '--filename=*.py',
         '--show-source',
+        '--benchmark',
         '--repeat',
         '--show-pep8',
-        #'-qq',
-        '-v',
+        #'--qq',
+        #'-v',
         BASE_DIR,
     ]
 
